﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using DbExample.Web.Models;
using DbExample.Web.Services;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.FormatProviders;
using Telerik.Windows.Documents.FormatProviders.Xaml;
using Telerik.Windows.Documents.Model;

namespace DbExample
{
    public partial class MainPage : UserControl
    {
        #region Constructors

        public MainPage()
        {
            StyleManager.ApplicationTheme = new Office_BlueTheme();
            InitializeComponent();
        }

        #endregion

        #region Events

        private void documentDomainDataSource_LoadedData(object sender, LoadedDataEventArgs e)
        {
            if (e.HasError)
            {
                System.Windows.MessageBox.Show(e.Error.ToString(), "Load Error", System.Windows.MessageBoxButton.OK);
                e.MarkErrorAsHandled();
            }
        }

        private void btnNew_Click(object sender, RoutedEventArgs e)
        {
            NewDocumentWindow dialog = new NewDocumentWindow();
            dialog.Closed += new EventHandler(newDoc_Closed);
            dialog.Show();
        }

        void newDoc_Closed(object sender, EventArgs e)
        {
            NewDocumentWindow dialog = (NewDocumentWindow)sender;
            string title = dialog.Title;
            if (!string.IsNullOrEmpty(title))
            {
                Document newDoc = new Document();
                newDoc.Title = title;

                newDoc.Content = this.CreateNewDocument();
                DocumentsDomainContext context = (DocumentsDomainContext)documentDomainDataSource.DomainContext;
                context.Documents.Add(newDoc);

                this.gridView.SelectedItem = newDoc;
            }
        }

        private string CreateNewDocument()
        {
            RadDocument doc = new RadDocument();
            doc.SectionDefaultPageMargin = new Telerik.Windows.Documents.Layout.Padding(8);

            XamlFormatProvider provider = new XamlFormatProvider();
            return provider.Export(doc);

        }

        private void Save_Click(object sender, RoutedEventArgs e)
        {
            this.documentDomainDataSource.SubmitChanges();
        }

        private void btnDelete_Click(object sender, RoutedEventArgs e)
        {
            if (this.gridView.SelectedItem == null)
            {
                return;
            }
            DocumentsDomainContext context = (DocumentsDomainContext)documentDomainDataSource.DomainContext;
            context.Documents.Remove((Document)this.gridView.SelectedItem);
        }

        #endregion


    }
}
